@@ -21,6 +21,7 @@ from .internal.openapi_client.api.endpoint import (
     get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get,
     get_endpoint_headers_api_v1_app_app_id_endpoint_endpoint_id_headers_get,
     get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get,
+    get_endpoint_stats_api_v1_app_app_id_endpoint_endpoint_id_stats_get,
     list_endpoints_api_v1_app_app_id_endpoint_get,
     patch_endpoint_headers_api_v1_app_app_id_endpoint_endpoint_id_headers_patch,
     recover_failed_webhooks_api_v1_app_app_id_endpoint_endpoint_id_recover_post,
@@ -70,6 +71,7 @@ from .internal.openapi_client.models.endpoint_message_out_payload import Endpoin
 from .internal.openapi_client.models.endpoint_out import EndpointOut
 from .internal.openapi_client.models.endpoint_secret_out import EndpointSecretOut
 from .internal.openapi_client.models.endpoint_secret_rotate_in import EndpointSecretRotateIn
+from .internal.openapi_client.models.endpoint_stats import EndpointStats
 from .internal.openapi_client.models.endpoint_update import EndpointUpdate
 from .internal.openapi_client.models.event_type_in import EventTypeIn
 from .internal.openapi_client.models.event_type_out import EventTypeOut
@@ -430,6 +432,13 @@ class Endpoint(ApiBase):
             json_body=endpoint_headers_in,
         )
 
+    def get_stats(self, app_id: str, endpoint_id: str) -> EndpointStats:
+        return get_endpoint_stats_api_v1_app_app_id_endpoint_endpoint_id_stats_get.sync(
+            client=self._client,
+            app_id=app_id,
+            endpoint_id=endpoint_id,
+        )
+
 
 class EventTypeAsync(ApiBase):
     async def list(self, options: EventTypeListOptions = EventTypeListOptions()) -> ListResponseEventTypeOut:
@@ -815,7 +824,16 @@ class ClientBase:
     def __init__(self, auth_token: str, options: SvixOptions = SvixOptions()) -> None:
         from . import __version__
 
-        host = options.server_url or DEFAULT_SERVER_URL
+        regional_url = None
+        region = auth_token.split(".")[-1]
+        if region == "us":
+            regional_url = "https://api.us.svix.com"
+        elif region == "eu":
+            regional_url = "https://api.eu.svix.com"
+        elif region == "in":
+            regional_url = "https://api.in.svix.com"
+
+        host = options.server_url or regional_url or DEFAULT_SERVER_URL
         client = AuthenticatedClient(
             base_url=host,
             token=auth_token,
