@@ -16,7 +16,7 @@ def _get_kwargs(
     endpoint_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/endpoint/{endpoint_id}/secret/".format(
         client.base_url, app_id=app_id, endpoint_id=endpoint_id
@@ -25,7 +25,7 @@ def _get_kwargs(
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     return {
@@ -64,7 +64,7 @@ def sync_detailed(
     endpoint_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EndpointSecretOut:
     """Get Endpoint Secret
 
@@ -77,7 +77,7 @@ def sync_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         EndpointSecretOut
@@ -114,7 +114,7 @@ def sync(
     endpoint_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EndpointSecretOut:
     """Get Endpoint Secret
 
@@ -127,7 +127,7 @@ def sync(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         EndpointSecretOut
@@ -146,7 +146,7 @@ async def asyncio_detailed(
     endpoint_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EndpointSecretOut:
     """Get Endpoint Secret
 
@@ -159,7 +159,7 @@ async def asyncio_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         EndpointSecretOut
@@ -194,7 +194,7 @@ async def asyncio(
     endpoint_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EndpointSecretOut:
     """Get Endpoint Secret
 
@@ -207,7 +207,7 @@ async def asyncio(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         EndpointSecretOut
