@@ -18,14 +18,14 @@ def _get_kwargs(
     limit: Union[Unset, None, int] = 50,
     with_content: Union[Unset, None, bool] = False,
     include_archived: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/event-type/".format(client.base_url)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -78,7 +78,7 @@ def sync_detailed(
     limit: Union[Unset, None, int] = 50,
     with_content: Union[Unset, None, bool] = False,
     include_archived: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseEventTypeOut:
     """List Event Types
 
@@ -89,7 +89,7 @@ def sync_detailed(
         limit (Union[Unset, None, int]):  Default: 50.
         with_content (Union[Unset, None, bool]):
         include_archived (Union[Unset, None, bool]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseEventTypeOut
@@ -130,7 +130,7 @@ def sync(
     limit: Union[Unset, None, int] = 50,
     with_content: Union[Unset, None, bool] = False,
     include_archived: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseEventTypeOut:
     """List Event Types
 
@@ -141,7 +141,7 @@ def sync(
         limit (Union[Unset, None, int]):  Default: 50.
         with_content (Union[Unset, None, bool]):
         include_archived (Union[Unset, None, bool]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseEventTypeOut
@@ -164,7 +164,7 @@ async def asyncio_detailed(
     limit: Union[Unset, None, int] = 50,
     with_content: Union[Unset, None, bool] = False,
     include_archived: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseEventTypeOut:
     """List Event Types
 
@@ -175,7 +175,7 @@ async def asyncio_detailed(
         limit (Union[Unset, None, int]):  Default: 50.
         with_content (Union[Unset, None, bool]):
         include_archived (Union[Unset, None, bool]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseEventTypeOut
@@ -214,7 +214,7 @@ async def asyncio(
     limit: Union[Unset, None, int] = 50,
     with_content: Union[Unset, None, bool] = False,
     include_archived: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseEventTypeOut:
     """List Event Types
 
@@ -225,7 +225,7 @@ async def asyncio(
         limit (Union[Unset, None, int]):  Default: 50.
         with_content (Union[Unset, None, bool]):
         include_archived (Union[Unset, None, bool]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseEventTypeOut
