@@ -19,7 +19,7 @@ def _get_kwargs(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/stats/app/{app_id}/ep/{endpoint_id}/attempt/".format(
         client.base_url, app_id=app_id, endpoint_id=endpoint_id
@@ -28,7 +28,7 @@ def _get_kwargs(
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -85,7 +85,7 @@ def sync_detailed(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> AttemptStatisticsResponse:
     """Get Ep Stats
 
@@ -96,7 +96,7 @@ def sync_detailed(
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         start_date (Union[Unset, None, datetime.datetime]):
         end_date (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         AttemptStatisticsResponse
@@ -137,7 +137,7 @@ def sync(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> AttemptStatisticsResponse:
     """Get Ep Stats
 
@@ -148,7 +148,7 @@ def sync(
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         start_date (Union[Unset, None, datetime.datetime]):
         end_date (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         AttemptStatisticsResponse
@@ -171,7 +171,7 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> AttemptStatisticsResponse:
     """Get Ep Stats
 
@@ -182,7 +182,7 @@ async def asyncio_detailed(
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         start_date (Union[Unset, None, datetime.datetime]):
         end_date (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         AttemptStatisticsResponse
@@ -221,7 +221,7 @@ async def asyncio(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> AttemptStatisticsResponse:
     """Get Ep Stats
 
@@ -232,7 +232,7 @@ async def asyncio(
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         start_date (Union[Unset, None, datetime.datetime]):
         end_date (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         AttemptStatisticsResponse
