@@ -51,7 +51,7 @@ class EventTypeUpdate:
 
         archived = dict_copy.pop("archived", UNSET)
 
-        schemas = dict_copy.pop("schemas")
+        schemas = dict_copy.pop("schemas", UNSET)
 
         event_type_update = cls(
             description=description,
